# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/moblyze/operation/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/moblyze/operation/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Moblyze\\Operation\\": "packages/moblyze/operation/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Moblyze\Operation\Providers\OperationServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Operation'  => Moblyze\Operation\Facades\Operation::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Moblyze\\OperationTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Moblyze\Operation\Providers\OperationServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Moblyze\Operation\Providers\OperationServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Moblyze\Operation\Providers\OperationServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/operation/{modulename}

**User**

    http://path-to-route-folder/user/operation/{modulename}

**Public**

    http://path-to-route-folder/operations


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/operation/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/operation/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/operation/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/operation/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/operation/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/operation/{modulename}/{slug}
    METHOD: GET