<?php

namespace Moblyze\Operation\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Operation\Models\Operation;

class OperationPolicy
{

    /**
     * Determine if the given user can view the operation.
     *
     * @param UserPolicy $user
     * @param Operation $operation
     *
     * @return bool
     */
    public function view(UserPolicy $user, Operation $operation)
    {
        if ($user->canDo('operation.operation.view') && $user->isAdmin()) {
            return true;
        }

        return $operation->user_id == user_id() && $operation->user_type == user_type();
    }

    /**
     * Determine if the given user can create a operation.
     *
     * @param UserPolicy $user
     * @param Operation $operation
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('operation.operation.create');
    }

    /**
     * Determine if the given user can update the given operation.
     *
     * @param UserPolicy $user
     * @param Operation $operation
     *
     * @return bool
     */
    public function update(UserPolicy $user, Operation $operation)
    {
        if ($user->canDo('operation.operation.edit') && $user->isAdmin()) {
            return true;
        }

        return $operation->user_id == user_id() && $operation->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given operation.
     *
     * @param UserPolicy $user
     * @param Operation $operation
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Operation $operation)
    {
        return $operation->user_id == user_id() && $operation->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given operation.
     *
     * @param UserPolicy $user
     * @param Operation $operation
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Operation $operation)
    {
        if ($user->canDo('operation.operation.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given operation.
     *
     * @param UserPolicy $user
     * @param Operation $operation
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Operation $operation)
    {
        if ($user->canDo('operation.operation.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
